def _eastern_to_western_numbers(nums):
    western = "٠١٢٣٤٥٦٧٨٩"
    result = ""
    for num in nums:
        if num in western:
            result += str(western.index(num))
        else:
            result += num
    return result


def _evaluate_digit(current_digit):
    if current_digit < 5:
        return current_digit * 2
    num_str = str(current_digit * 2)
    return int(num_str[0]) + int(num_str[1])


def is_valid_saudi_id(saudi_id):
    string_id = _eastern_to_western_numbers(str(saudi_id)).strip()

    if len(string_id) != 10 or (not string_id.isdigit()) or (not string_id[0] in "12"):
        return False

    numbers_sum = 0
    for idx in range(0, len(string_id)):
        if idx % 2 == 0:
            numbers_sum += _evaluate_digit(int(string_id[idx]))
        else:
            numbers_sum += int(string_id[idx])

    return numbers_sum % 10 == 0



from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

DESCRIPTION = 'A tiny package that helps you validate Saudi national or iqama ids'
LONG_DESCRIPTION = (here / "README.md").read_text(encoding="utf-8")

setup(
    # the name must match the folder name 'verysimplemodule'
    name="saudi-ids-validator",
    version="0.0.1",
    author="Mohammed Alzaid",
    author_email="m7md.alzaid5@gmail.com",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    url="https://github.com/malzaid0/saudi-id-validator-pypi/",
    packages=find_packages(),
    install_requires=[],  # add any additional packages that
    # needs to be installed along with your package. Eg: 'caer'

    keywords=["saudi", "saudi national", "iqama", "saudi id", "saudi arabia", "saudi id validator"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    project_urls={
        "Bug Reports": "https://github.com/malzaid0/saudi-id-validator-pypi/issues",
        "Source": "https://github.com/malzaid0/saudi-id-validator-pypi/",
    },
)
